@@ -1,4 +1,4 @@
-/*  $Id: ResultPage.cpp,v 1.5 2004/06/12 01:54:05 sarrazip Exp $
+/*  $Id: ResultPage.cpp,v 1.6 2010/05/19 01:12:10 sarrazip Exp $
     ResultPage.cpp - Text buffer containing the results of a search
 
     sagasu - GNOME tool to find strings in a set of files
@@ -34,19 +34,20 @@ using namespace std;
 
 
 ResultPage::ResultPage()
+  : vbox(gtk_vbox_new(FALSE, 0)),
+    sw(gtk_scrolled_window_new(NULL, NULL)),
+    text_view(gtk_text_view_new()),
+    status_label(gtk_label_new(_("No results yet."))),
+    next_search_pos(0)
 {
-    text_view = gtk_text_view_new();
     gtk_text_view_set_editable(GTK_TEXT_VIEW(text_view), false);
 
-    sw = gtk_scrolled_window_new(NULL, NULL);
     gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(sw),
 				GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
     gtk_container_add(GTK_CONTAINER(sw), text_view);
 
-    status_label = gtk_label_new(_("No results yet."));
     gtk_misc_set_alignment(GTK_MISC(status_label), 0.0, 0.5);
 
-    vbox = gtk_vbox_new(FALSE, 0);
     gtk_box_pack_start(GTK_BOX(vbox), sw, TRUE, TRUE, 0);
     gtk_box_pack_end(GTK_BOX(vbox), status_label, FALSE, FALSE, 0);
 
@@ -59,8 +60,6 @@ ResultPage::ResultPage()
 	*/
 
     gtk_widget_show_all(GTK_WIDGET(vbox));
-
-    next_search_pos = 0;
 }
 
 
@@ -104,7 +103,7 @@ ResultPage::insert_text(const string &s)
     GtkTextBuffer *buf = gtk_text_view_get_buffer(GTK_TEXT_VIEW(text_view));
     GtkTextIter iter;
     gtk_text_buffer_get_end_iter(GTK_TEXT_BUFFER(buf), &iter);
-    GCharPtr u = u8(s);
+    GCharPtr u(u8(s));
     gtk_text_buffer_insert(GTK_TEXT_BUFFER(buf), &iter, u.get(), -1);
 }
 
