@@ -1,4 +1,4 @@
-/*  $Id: ResultPage.h,v 1.2 2004/06/12 01:54:05 sarrazip Exp $
+/*  $Id: ResultPage.h,v 1.3 2010/05/19 01:12:10 sarrazip Exp $
     ResultPage.h - Text buffer containing the results of a search
 
     sagasu - GNOME tool to find strings in a set of files
@@ -70,6 +70,10 @@ private:
     GtkWidget *text_view;  // text view
     GtkWidget *status_label;
     gint next_search_pos;  // index into the text buffer
+
+    // Forbidden operations:
+    ResultPage(const ResultPage &);
+    ResultPage &operator = (const ResultPage &);
 };
 
 
