@@ -1,4 +1,4 @@
-/*  $Id: SagasuApp.cpp,v 1.17 2005/08/09 00:11:28 sarrazip Exp $
+/*  $Id: SagasuApp.cpp,v 1.23 2010/05/31 00:11:49 sarrazip Exp $
     SagasuApp.cpp - Class representing the main window
 
     sagasu - GNOME tool to find strings in a set of files
@@ -29,6 +29,7 @@
 #define N_(String) gettext_noop (String)
 
 #include <libgnomeui/libgnomeui.h>
+#include <gtk/gtk.h>
 #include <gdk/gdk.h>
 #include <libgnome/gnome-config.h>
 #include <libgnome/gnome-sound.h>
@@ -43,13 +44,12 @@
 #include <errno.h>
 
 #include <iostream>
+#include <fstream>
+#include <sstream>
 #include <algorithm>  /* required by g++ 2.95.3 to define min() */
 
 using namespace std;
 
-#undef sprintf
-#define sprintf @  /* forbidden */
-
 
 ///////////////////////////////////////////////////////////////////////////////
 
@@ -98,7 +98,7 @@ reaper(int)
 
 /*static*/
 gboolean
-input_channel_ready_cb(GIOChannel *source,
+input_channel_ready_cb(GIOChannel * /*source*/,
 			GIOCondition condition,
 			gpointer data)
 {
@@ -107,7 +107,7 @@ input_channel_ready_cb(GIOChannel *source,
 
 
 gboolean
-result_page_button_press_cb(GtkWidget *text_view,
+result_page_button_press_cb(GtkWidget * /*text_view*/,
 			    GdkEventButton *e,
 			    gpointer data)
 {
@@ -147,48 +147,83 @@ key_press_in_search_field_cb(GtkWidget *, GdkEventKey *event, gpointer)
 }
 
 
+static
+gboolean
+onKeyPressInAbout(GtkWidget *about, GdkEventKey *event, gpointer)
+{
+    g_return_val_if_fail(event != NULL, TRUE);
+
+    switch (event->keyval)
+    {
+	case GDK_Escape:
+	    gtk_dialog_response(GTK_DIALOG(about), GTK_RESPONSE_OK);
+	    return TRUE;
+
+	default:
+	    return FALSE;
+    }
+}
+
+
 void
-about_cb(GtkWidget *widget, gpointer data)
+about_cb(GtkWidget * /*widget*/, gpointer /*data*/)
 {
     static GtkWidget *dialog = NULL;
 
-    GtkWidget *app = (GtkWidget *) data;
-
-    if (dialog != NULL) 
+    if (dialog != NULL)
     {
 	g_assert(GTK_WIDGET_REALIZED(dialog));
 	gdk_window_show(dialog->window);
 	gdk_window_raise(dialog->window);
     }
     else
-    {        
+    {
 	const gchar *authors[] =
 	{
 	    "Pierre Sarrazin <http://sarrazip.com/>",
 	    NULL
 	};
 
-	string logo_filename = 
+	string logo_filename =
 		get_dir(PIXMAPDIR, "PIXMAPDIR") + PACKAGE ".png";
 
 	GdkPixbuf *logo = gdk_pixbuf_new_from_file(
-					logo_filename.c_str(), NULL); 
+					logo_filename.c_str(), NULL);
 	string copyright = string(
-	     "Copyright (C) 2002-2004 Pierre Sarrazin <http://sarrazip.com/>\n")
+	     "Copyright (C) 2002-2006 Pierre Sarrazin <http://sarrazip.com/>\n")
 			+ _("Distributed under the GNU General Public License");
-	dialog = gnome_about_new(_("Sagasu"), VERSION,
-	    copyright.c_str(),
-	    _("GNOME tool to find strings in a set of files"),
-	    authors, NULL, NULL, logo);
 
-	gtk_window_set_transient_for(GTK_WINDOW(dialog), GTK_WINDOW(app));	
+	GtkWidget *about = gtk_about_dialog_new();
+	gtk_about_dialog_set_name(GTK_ABOUT_DIALOG(about), _("Sagasu"));
+	gtk_about_dialog_set_version(GTK_ABOUT_DIALOG(about), VERSION);
+	gtk_about_dialog_set_copyright(GTK_ABOUT_DIALOG(about), copyright.c_str());
+	gtk_about_dialog_set_comments(GTK_ABOUT_DIALOG(about),
+			    _("GNOME tool to find strings in a set of files"));
+	gtk_about_dialog_set_authors(GTK_ABOUT_DIALOG(about), authors);
+	if (logo != NULL)
+	    gtk_about_dialog_set_logo(GTK_ABOUT_DIALOG(about), logo);
+
+	{
+	    ifstream licenseFile(
+		    (get_dir(PKGDATADIR, "PKGDATADIR") + "COPYING").c_str());
+	    if (licenseFile.good())
+	    {
+		stringstream ss;
+		ss << licenseFile.rdbuf();
+		gtk_about_dialog_set_license(GTK_ABOUT_DIALOG(about),
+							ss.str().c_str());
+	    }
+	}
+
 	if (logo != NULL)
 	    gdk_pixbuf_unref(logo);
 
-	g_signal_connect(G_OBJECT(dialog), "destroy",
-				G_CALLBACK(gtk_widget_destroyed), &dialog); 
+	g_signal_connect(G_OBJECT(about), "key-press-event",
+			    G_CALLBACK(onKeyPressInAbout), NULL);
 
-	gtk_widget_show(dialog);
+	gtk_dialog_run(GTK_DIALOG(about));
+	gtk_widget_hide(about);
+	gtk_widget_destroy(about);
     }
 }
 
@@ -265,10 +300,6 @@ GnomeUIInfo help_menu[] =
 	N_("Go to Sagasu _Home Page"),
 	N_("Open the Sagasu Home Page in a browser"),
 	::home_page_cb),
-    GNOMEUIINFO_ITEM_NONE(
-	N_("View this Program's _License (GPL)"),
-	N_("View the text of the license that covers this program"),
-	::view_license_cb),
     GNOMEUIINFO_MENU_ABOUT_ITEM(about_cb, NULL),
     GNOMEUIINFO_END
 };
@@ -348,7 +379,7 @@ SagasuApp::get_instance()
 SagasuApp::SagasuApp(const string &init_search_expr,
 			const string &init_search_dir)
   : appwin(NULL),
-  
+
     search_string_entry(NULL),
     file_patterns_entry(NULL),
     search_dir_entry(NULL),
@@ -561,7 +592,7 @@ SagasuApp::build_user_interface(const std::string &init_search_expr,
 				_("_Browse..."), ::browse_search_dir_cb },
 	{ &default_editor_cmd_button, editor_cmd_entry, _("Edit_or command:"),
 				_("D_efault"), ::default_editor_cmd_cb },
-	{ NULL, NULL, NULL, NULL },
+	{ NULL, NULL, NULL, NULL, NULL },
     };
 
     size_t i;
@@ -827,7 +858,9 @@ SagasuApp::search_cb(GtkWidget *, gpointer)
     g_return_if_fail(input_channel != NULL);
     if (g_io_channel_set_encoding(input_channel, NULL, NULL)
 				    != G_IO_STATUS_NORMAL)
+    {
 	g_return_if_reached();
+    }
 
     (void) g_io_add_watch(input_channel,
 		GIOCondition(G_IO_IN | G_IO_HUP | G_IO_ERR | G_IO_NVAL),
@@ -986,8 +1019,8 @@ SagasuApp::create_search_process(const string &target_expr,
 	snprintf(depth, sizeof(depth), "%d", (int) recursion_depth);
 
 	execl("/usr/bin/perl", "perl", script.c_str(),
-		target_expr.c_str(), 
-		search_dir.c_str(), 
+		target_expr.c_str(),
+		search_dir.c_str(),
 		file_patterns.c_str(),
 		match_case ? "1" : "0",
 		exclude_cvs_dirs ? "1" : "0",
@@ -1077,7 +1110,7 @@ SagasuApp::show_num_matching_lines()
 
 
 gboolean
-SagasuApp::input_channel_ready(GIOCondition condition)
+SagasuApp::input_channel_ready(GIOCondition /*condition*/)
 {
     if (input_fd == -1)
     {
@@ -1092,9 +1125,7 @@ SagasuApp::input_channel_ready(GIOCondition condition)
 	int e = errno;
 	if (bytes_read < 0)
 	{
-	    g_warning(
-		    (string("read() failed on source fd: ")
-		    + strerror(e)).c_str());
+	    g_warning("read() failed on source fd %d: %s", input_fd, strerror(e));
 	}
 
 	close_input();
@@ -1187,8 +1218,8 @@ SagasuApp::get_result_text_line_for_pos(gint pos_in_chars) const
     gtk_text_iter_forward_chars(&line_end_it, line_length);
 
     // Get the line itself, and convert it from UTF-8 to Latin-1:
-    GCharPtr utf8_line = gtk_text_buffer_get_text(
-				buf, &line_start_it, &line_end_it, true);
+    GCharPtr utf8_line(gtk_text_buffer_get_text(
+				buf, &line_start_it, &line_end_it, true));
     return latin1_string(utf8_line.get());
 }
 
@@ -1288,7 +1319,7 @@ get_config_var(const string &var, const string &utf8_default)
 */
 {
     string path = get_config_var_path(var);
-    GCharPtr s = gnome_config_get_string(path.c_str());
+    GCharPtr s(gnome_config_get_string(path.c_str()));
     if (s.get() != NULL)
 	return s.get();
     gnome_config_set_string(path.c_str(), utf8_default.c_str());
@@ -1708,14 +1739,6 @@ SagasuApp::home_page_cb(GtkWidget *, gpointer)
 }
 
 
-void
-SagasuApp::view_license_cb(GtkWidget *, gpointer)
-{
-    string url = "file:" + get_dir(PKGDATADIR, "PKGDATADIR") + "COPYING";
-    show_url(url, appwin, _("Error when opening license file"));
-}
-
-
 ///////////////////////////////////////////////////////////////////////////////
 //
 // CALLBACKS METHODS
