@@ -1,4 +1,4 @@
-/*  $Id: SagasuApp.h,v 1.10 2004/06/12 01:54:05 sarrazip Exp $
+/*  $Id: SagasuApp.h,v 1.11 2010/05/19 01:12:10 sarrazip Exp $
     SagasuApp.h - Class representing the main window
 
     sagasu - GNOME tool to find strings in a set of files
@@ -193,6 +193,9 @@ private:
     void display_wait_cursor();
     void remove_wait_cursor();
 
+    // Forbidden operations:
+    SagasuApp(const SagasuApp &);
+    SagasuApp &operator = (const SagasuApp &);
 };
 
 
