@@ -1,4 +1,4 @@
-/*  $Id: main.cpp,v 1.4 2004/06/12 01:54:05 sarrazip Exp $
+/*  $Id: main.cpp,v 1.5 2009/03/16 02:38:24 sarrazip Exp $
     main.cpp - main() function to initialize the GNOME 2 application
 
     sagasu - GNOME tool to find strings in a set of files
@@ -55,7 +55,8 @@ static
 poptContext
 get_poptContext(GnomeProgram *program)
 {
-    GValue value = { 0, };
+    GValue value;
+    ::memset(&value, '\0', sizeof(value));
     g_value_init(&value, G_TYPE_POINTER);
     g_object_get_property(G_OBJECT(program),
 			    GNOME_PARAM_POPT_CONTEXT, &value);
