@@ -1,4 +1,4 @@
-/*  $Id: util.cpp,v 1.6 2004/06/12 01:54:05 sarrazip Exp $
+/*  $Id: util.cpp,v 1.8 2010/05/31 00:11:49 sarrazip Exp $
     util.cpp - Various utilities
 
     sagasu - GNOME tool to find strings in a set of files
@@ -23,6 +23,8 @@
 #include "util.h"
 
 #include <assert.h>
+#include <stdlib.h>
+#include <string.h>
 #include <libintl.h>
 #define _(String) gettext (String)
 #define gettext_noop(String) String
@@ -102,7 +104,7 @@ get_dir(const char *default_value, const char *env_var_name)
 {
     const char *s = getenv(env_var_name);
     string dir = (s != NULL ? s : default_value);
-    
+
     if (!dir.empty() && dir[dir.length() - 1] != '/')
 	dir += '/';
 
@@ -125,6 +127,7 @@ error_dialog(GtkWidget *window, const string &utf8_message)
 			GTK_DIALOG_DESTROY_WITH_PARENT,
 			GTK_MESSAGE_ERROR,
 			GTK_BUTTONS_CLOSE,
+			"%s",
 			utf8_message.c_str());
     gtk_dialog_run(GTK_DIALOG(dlg));
     gtk_widget_destroy(dlg);
