@@ -1,4 +1,4 @@
-/*  $Id: util.h,v 1.7 2004/06/12 01:54:05 sarrazip Exp $
+/*  $Id: util.h,v 1.8 2010/05/19 01:12:10 sarrazip Exp $
     util.h - Various utilities
 
     sagasu - GNOME tool to find strings in a set of files
@@ -44,6 +44,10 @@ public:
 
 private:
     gchar *ptr;
+
+    // Forbidden operations:
+    GCharPtr(const GCharPtr &);
+    GCharPtr &operator = (const GCharPtr &);
 };
 
 
